# mypy-boto3-emr

[![PyPI - mypy-boto3-emr](https://img.shields.io/pypi/v/mypy-boto3-emr.svg?color=blue)](https://pypi.org/project/mypy-boto3-emr)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-emr.svg?color=blue)](https://pypi.org/project/mypy-boto3-emr)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-emr](#mypy-boto3-emr)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)

Type annotations for
[boto3.EMR 1.14.0](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/emr.html#EMR) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.4](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `EMR` service.

```bash
python -m pip install boto3-stubs[emr]
```

Use `boto3` with `mypy_boto3_emr` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_emr import EMRClient

# Now mypy can check if your code is valid.
client: EMRClient = boto3.client("emr")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: EMRClient = session.client("emr")



# Waiters are also supported

import mypy_boto3_emr.waiter as emr_waiters

cluster_running_waiter: emr_waiters.ClusterRunningWaiter = client.get_waiter("cluster_running")
cluster_terminated_waiter: emr_waiters.ClusterTerminatedWaiter = client.get_waiter("cluster_terminated")
step_complete_waiter: emr_waiters.StepCompleteWaiter = client.get_waiter("step_complete")


# Annotated paginators are included as well

import mypy_boto3_emr.paginator as emr_paginators

list_bootstrap_actions_paginator: emr_paginators.ListBootstrapActionsPaginator = client.get_paginator("list_bootstrap_actions")
list_clusters_paginator: emr_paginators.ListClustersPaginator = client.get_paginator("list_clusters")
list_instance_fleets_paginator: emr_paginators.ListInstanceFleetsPaginator = client.get_paginator("list_instance_fleets")
list_instance_groups_paginator: emr_paginators.ListInstanceGroupsPaginator = client.get_paginator("list_instance_groups")
list_instances_paginator: emr_paginators.ListInstancesPaginator = client.get_paginator("list_instances")
list_security_configurations_paginator: emr_paginators.ListSecurityConfigurationsPaginator = client.get_paginator("list_security_configurations")
list_steps_paginator: emr_paginators.ListStepsPaginator = client.get_paginator("list_steps")
```

## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_emr` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python
import boto3

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("emr")

session_client = boto3.Session().client("emr")
```